@@ -3,13 +3,13 @@ from __future__ import annotations
 import abc
 import os
 import threading
-from typing import TYPE_CHECKING, Any, Callable, Literal, Union
+from typing import TYPE_CHECKING, Any, Final, Literal
 
 import polars._utils.logging
 from polars._utils.cache import LRUCache
 from polars._utils.logging import eprint, verbose
 from polars._utils.unstable import issue_unstable_warning
-from polars.io.cloud._utils import NoPickleOption
+from polars.io.cloud._utils import POLARS_STORAGE_CONFIG_KEYS, NoPickleOption
 from polars.io.cloud.credential_provider._providers import (
     CachedCredentialProvider,
     CachingCredentialProvider,
@@ -22,16 +22,17 @@ from polars.io.cloud.credential_provider._providers import (
 )
 
 if TYPE_CHECKING:
-    import sys
+    from collections.abc import Callable
+    from typing import TypeAlias
 
-    if sys.version_info >= (3, 10):
-        from typing import TypeAlias
-    else:
-        from typing_extensions import TypeAlias
+    from polars._typing import StorageOptionsDict
 
-# https://docs.rs/object_store/latest/object_store/enum.ClientConfigKey.html
-OBJECT_STORE_CLIENT_OPTIONS: frozenset[str] = frozenset(
+
+# `storage_options` keys that are ignored when auto-initializing a credential provider.
+AUTOINIT_IGNORED_KEYS: Final[frozenset[str]] = frozenset(
     [
+        # Object store client options
+        # https://docs.rs/object_store/latest/object_store/enum.ClientConfigKey.html
         "allow_http",
         "allow_invalid_certificates",
         "connect_timeout",
@@ -49,12 +50,25 @@ OBJECT_STORE_CLIENT_OPTIONS: frozenset[str] = frozenset(
         "proxy_excludes",
         "timeout",
         "user_agent",
+        *POLARS_STORAGE_CONFIG_KEYS,
+        # Azure
+        "azure_use_azure_cli",
+        "use_azure_cli",
+        # AWS
+        "aws_request_payer",
+        "request_payer",
+        # GCS
+        "google_bucket",
+        "google_bucket_name",
+        "bucket",
+        "bucket_name",
     ]
 )
 
-CredentialProviderBuilderReturn: TypeAlias = Union[
-    CredentialProvider, CredentialProviderFunction, None
-]
+
+CredentialProviderBuilderReturn: TypeAlias = (
+    CredentialProvider | CredentialProviderFunction | None
+)
 
 
 class CredentialProviderBuilder:
@@ -299,13 +313,18 @@ class AutoInit(CredentialProviderBuilderImpl):
         return self.cls.__name__
 
 
+DEFAULT_CREDENTIAL_PROVIDER: CredentialProviderFunction | Literal["auto"] | None = (
+    "auto"
+)
+
+
 def _init_credential_provider_builder(
     credential_provider: CredentialProviderFunction
     | CredentialProviderBuilder
     | Literal["auto"]
     | None,
     source: Any,
-    storage_options: dict[str, Any] | None,
+    storage_options: StorageOptionsDict | None,
     caller_name: str,
 ) -> CredentialProviderBuilder | None:
     def f() -> CredentialProviderBuilder | None:
@@ -337,12 +356,24 @@ def _init_credential_provider_builder(
                 credential_provider
             )
 
+        if DEFAULT_CREDENTIAL_PROVIDER is None:
+            return None
+
         if (first_scan_path := _first_scan_path(source)) is None:
             return None
 
         if (scheme := _get_path_scheme(first_scan_path)) is None:
             return None
 
+        def get_default_credential_provider() -> CredentialProviderBuilder | None:
+            return (
+                CredentialProviderBuilder.from_initialized_provider(
+                    DEFAULT_CREDENTIAL_PROVIDER
+                )
+                if DEFAULT_CREDENTIAL_PROVIDER != "auto"
+                else None
+            )
+
         if _is_azure_cloud(scheme):
             tenant_id = None
             storage_account = None
@@ -363,9 +394,7 @@ def _init_credential_provider_builder(
                         tenant_id = v
                     elif k in {"azure_storage_account_name", "account_name"}:
                         storage_account = v
-                    elif k in {"azure_use_azure_cli", "use_azure_cli"}:
-                        continue
-                    elif k in OBJECT_STORE_CLIENT_OPTIONS:
+                    elif k in AUTOINIT_IGNORED_KEYS:
                         continue
                     else:
                         # We assume some sort of access key was given, so we
@@ -380,6 +409,9 @@ def _init_credential_provider_builder(
                 or storage_account
             )
 
+            if (default := get_default_credential_provider()) is not None:
+                return default
+
             return CredentialProviderBuilder(
                 AutoInit(
                     CredentialProviderAzure,
@@ -413,7 +445,7 @@ def _init_credential_provider_builder(
                         "endpoint_url",
                     }:
                         has_endpoint_url = True
-                    elif k in OBJECT_STORE_CLIENT_OPTIONS:
+                    elif k in AUTOINIT_IGNORED_KEYS:
                         continue
                     else:
                         # We assume this is some sort of access key
@@ -427,6 +459,12 @@ def _init_credential_provider_builder(
                     )
                     raise ValueError(msg)
 
+            if (
+                unhandled_key is None
+                and (default := get_default_credential_provider()) is not None
+            ):
+                return default
+
             return CredentialProviderBuilder(
                 AutoInit(
                     CredentialProviderAWS,
@@ -448,14 +486,7 @@ def _init_credential_provider_builder(
                     # https://docs.rs/object_store/latest/object_store/gcp/enum.GoogleConfigKey.html
                     if k in {"token", "bearer_token"}:
                         token = v
-                    elif k in {
-                        "google_bucket",
-                        "google_bucket_name",
-                        "bucket",
-                        "bucket_name",
-                    }:
-                        continue
-                    elif k in OBJECT_STORE_CLIENT_OPTIONS:
+                    elif k in AUTOINIT_IGNORED_KEYS:
                         continue
                     else:
                         # We assume some sort of access key was given, so we
@@ -477,6 +508,9 @@ def _init_credential_provider_builder(
                     InitializedCredentialProvider(UserProvidedGCPToken(token))
                 )
 
+            if (default := get_default_credential_provider()) is not None:
+                return default
+
             return CredentialProviderBuilder(AutoInit(CredentialProviderGCP))
 
         return None
